@@ -95,7 +95,10 @@ class Runner:
                 writer.writerow(self.columns)
                 writer.writerows(self.rows)
 
-            os.remove(self.csv_out_file)
+            try:
+                os.remove(self.csv_out_file)
+            except FileNotFoundError:
+                pass
             os.rename(self.csv_out_file + '_', self.csv_out_file)
 
         row = tuple(instance_data.get(key, None) for key in self.columns)
